@@ -64,7 +64,7 @@
 #' \code{\link[evmix:kdengpdcon]{qkdengpdcon}} gives the quantile function and 
 #' \code{\link[evmix:kdengpdcon]{rkdengpdcon}} gives a random sample.
 #' 
-#' @note Unlike all the other extreme value mixture model functions the 
+#' @note Unlike most of the other extreme value mixture model functions the 
 #' \code{\link[evmix:kdengpdcon]{kdengpdcon}} functions have not been vectorised as
 #' this is not appropriate. The main inputs (\code{x}, \code{p} or \code{q})
 #' must be either a scalar or a vector, which also define the output length.
@@ -108,9 +108,11 @@
 #' 
 #' Wand, M. and Jones, M.C. (1995). Kernel Smoothing. Chapman && Hall.
 #' 
-#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}. Based on code
-#' by Anna MacDonald produced for MATLAB.
+#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}.
 #'
+#' @section Acknowledgments: Based on code
+#' by Anna MacDonald produced for MATLAB.
+#' 
 #' @seealso \code{\link[evmix:kernels]{kernels}}, \code{\link[evmix:kfun]{kfun}},
 #' \code{\link[stats:density]{density}}, \code{\link[stats:bandwidth]{bw.nrd0}}
 #' and \code{\link[ks:kde.1d]{dkde}} in \code{\link[ks:kde.1d]{ks}} package.
@@ -121,7 +123,9 @@
 #' 
 #' @examples
 #' \dontrun{
-#' par(mfrow=c(2,2))
+#' set.seed(1)
+#' par(mfrow = c(2, 2))
+#' 
 #' kerncentres=rnorm(500, 0, 1)
 #' xx = seq(-4, 4, 0.01)
 #' hist(kerncentres, breaks = 100, freq = FALSE)
@@ -158,14 +162,14 @@ dkdengpdcon <- function(x, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   xi = 0, phiu = TRUE, bw = NULL, kernel = "gaussian", log = FALSE) {
   
   # Check properties of inputs
-  check.quant(x, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(x, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.param(param = u)
-  check.param(param = xi)
+  check.param(u)
+  check.param(xi)
   check.phiu(phiu)
-  check.logic(logicarg = log)
+  check.logic(log)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -190,7 +194,7 @@ dkdengpdcon <- function(x, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   }
   lambda = klambda(bw, kernel, lambda)
   
-  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)))
+  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)), allowscalar = TRUE) # scalar only
      
   pu = pkdenx(u, kerncentres, lambda, kernel)
   if (is.logical(phiu)) {
@@ -203,7 +207,7 @@ dkdengpdcon <- function(x, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   du = kdenx(u, kerncentres, lambda, kernel)
   sigmau = phiu / (phib * du)
   
-  check.posparam(param = sigmau)
+  check.posparam(sigmau)
   
   dkdengpd(x, kerncentres, lambda, u, sigmau, xi, phiu, kernel = kernel, log = log)
 }
@@ -219,14 +223,14 @@ pkdengpdcon <- function(q, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   xi = 0, phiu = TRUE, bw = NULL, kernel = "gaussian", lower.tail = TRUE) {
   
   # Check properties of inputs
-  check.quant(q, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(q, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.param(param = u)
-  check.param(param = xi)
+  check.param(u)
+  check.param(xi)
   check.phiu(phiu)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -251,7 +255,7 @@ pkdengpdcon <- function(q, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   }
   lambda = klambda(bw, kernel, lambda)
   
-  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)))
+  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)), allowscalar = TRUE) # scalar only
 
   pu = pkdenx(u, kerncentres, lambda, kernel)
   if (is.logical(phiu)) {
@@ -264,7 +268,7 @@ pkdengpdcon <- function(q, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   du = kdenx(u, kerncentres, lambda, kernel)
   sigmau = phiu / (phib * du)
   
-  check.posparam(param = sigmau)
+  check.posparam(sigmau)
   
   pkdengpd(q, kerncentres, lambda, u, sigmau, xi, phiu, kernel = kernel, lower.tail = lower.tail)
 }
@@ -279,14 +283,14 @@ qkdengpdcon <- function(p, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   xi = 0, phiu = TRUE, bw = NULL, kernel = "gaussian", lower.tail = TRUE) {
   
   # Check properties of inputs
-  check.prob(p, allowmiss = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.prob(p, allowna = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.param(param = u)
-  check.param(param = xi)
+  check.param(u)
+  check.param(xi)
   check.phiu(phiu)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
     
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -307,7 +311,7 @@ qkdengpdcon <- function(p, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   }
   lambda = klambda(bw, kernel, lambda)
   
-  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)))
+  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)), allowscalar = TRUE) # scalar only
     
   pu = pkdenx(u, kerncentres, lambda, kernel)
   if (is.logical(phiu)) {
@@ -320,7 +324,7 @@ qkdengpdcon <- function(p, kerncentres, lambda = NULL, u = as.vector(quantile(ke
   du = kdenx(u, kerncentres, lambda, kernel)
   sigmau = phiu / (phib * du)
   
-  check.posparam(param = sigmau)
+  check.posparam(sigmau)
   
   qkdengpd(p, kerncentres, lambda, u, sigmau, xi, phiu, kernel = kernel, lower.tail = lower.tail)
 }
@@ -336,35 +340,14 @@ rkdengpdcon <- function(n = 1, kerncentres, lambda = NULL, u = as.vector(quantil
   
   # Check properties of inputs
   check.n(n)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.param(param = u)
-  check.param(param = xi)
+  check.param(u)
+  check.param(xi)
   check.phiu(phiu)
     
-  kernel = ifelse(kernel == "rectangular", "uniform", kernel)
-  kernel = ifelse(kernel == "normal", "gaussian", kernel)
-
-  if (any(!is.finite(kerncentres))) warning("non-finite kernel centres are dropped")
-
-  kerncentres = kerncentres[is.finite(kerncentres)]
-  check.quant(kerncentres)
-  nk = length(kerncentres)
-
-  if (is.null(lambda) & is.null(bw)) {
-    if (nk == 1) {
-      stop("Automated bandwidth estimation requires 2 or more kernel centres")
-    } else if (nk < 10) {
-      warning("Automated bandwidth estimation unreliable with less than 10 kernel centres")
-    }
-    bw = bw.nrd0(kerncentres)
-  }
-  lambda = klambda(bw, kernel, lambda)
-  
-  check.inputn(c(length(lambda), length(u), length(xi), length(phiu)))
-  
   if (any(xi == 1)) stop("shape cannot be 1")
 
-  qkdengpdcon(runif(n), kerncentres, lambda, u, xi, phiu, kernel = kernel)
+  qkdengpdcon(runif(n), kerncentres, lambda, u, xi, phiu, bw, kernel)
 }
