@@ -93,7 +93,9 @@
 #' 
 #' @examples
 #' \dontrun{
-#' par(mfrow=c(2,2))
+#' set.seed(1)
+#' par(mfrow = c(2, 2))
+#' 
 #' x = rlognormgpdcon(1000)
 #' xx = seq(-1, 10, 0.01)
 #' hist(x, breaks = 100, freq = FALSE, xlim = c(-1, 10))
@@ -129,15 +131,16 @@ dlognormgpdcon <- function(x, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
   xi = 0, phiu = TRUE, log = FALSE) {
 
   # Check properties of inputs
-  check.quant(x, allowmiss = TRUE, allowinf = TRUE)
-  check.param(param = lnmean, allowvec = TRUE)
-  check.posparam(param = lnsd, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE) # threshold also positive for log-normal
-  check.param(param = xi, allowvec = TRUE)
+  check.quant(x, allowna = TRUE, allowinf = TRUE)
+  check.param(lnmean, allowvec = TRUE)
+  check.posparam(lnsd, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = log)
+  check.logic(log)
 
-  n = check.inputn(c(length(x), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)))
+  n = check.inputn(c(length(x), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)),
+                   allowscalar = TRUE)
 
   if (any(is.infinite(x))) warning("infinite quantiles set to NA")
 
@@ -159,7 +162,7 @@ dlognormgpdcon <- function(x, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
   
   sigmau = phiu / (phib * dlnorm(u, lnmean, lnsd))
   
-  check.posparam(param = sigmau, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
   
   dlognormgpd(x, lnmean, lnsd, u, sigmau, xi, phiu, log)
 }
@@ -174,15 +177,16 @@ plognormgpdcon <- function(q, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
   xi = 0, phiu = TRUE, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.quant(q, allowmiss = TRUE, allowinf = TRUE)
-  check.param(param = lnmean, allowvec = TRUE)
-  check.posparam(param = lnsd, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.quant(q, allowna = TRUE, allowinf = TRUE)
+  check.param(lnmean, allowvec = TRUE)
+  check.posparam(lnsd, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
-  n = check.inputn(c(length(q), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)))
+  n = check.inputn(c(length(q), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)),
+                   allowscalar = TRUE)
 
   if (any(is.infinite(q))) warning("infinite quantiles set to NA")
 
@@ -204,7 +208,7 @@ plognormgpdcon <- function(q, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
   
   sigmau = phiu / (phib * dlnorm(u, lnmean, lnsd))
   
-  check.posparam(param = sigmau, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
 
   plognormgpd(q, lnmean, lnsd, u, sigmau, xi, phiu, lower.tail)
 }
@@ -219,15 +223,16 @@ qlognormgpdcon <- function(p, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
   xi = 0, phiu = TRUE, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.prob(p, allowmiss = TRUE)
-  check.param(param = lnmean, allowvec = TRUE)
-  check.posparam(param = lnsd, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.prob(p, allowna = TRUE)
+  check.param(lnmean, allowvec = TRUE)
+  check.posparam(lnsd, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
-  n = check.inputn(c(length(p), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)))
+  n = check.inputn(c(length(p), length(lnmean), length(lnsd), length(u), length(xi), length(phiu)),
+                   allowscalar = TRUE)
 
   p = rep(p, length.out = n)
   lnmean = rep(lnmean, length.out = n)
@@ -245,7 +250,7 @@ qlognormgpdcon <- function(p, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
     
   sigmau = phiu / (phib * dlnorm(u, lnmean, lnsd))
   
-  check.posparam(param = sigmau, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
     
   qlognormgpd(p, lnmean, lnsd, u, sigmau, xi, phiu, lower.tail)
 }
@@ -261,13 +266,14 @@ rlognormgpdcon <- function(n = 1, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean,
 
   # Check properties of inputs
   check.n(n)
-  check.param(param = lnmean, allowvec = TRUE)
-  check.posparam(param = lnsd, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.param(lnmean, allowvec = TRUE)
+  check.posparam(lnsd, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
 
-  n = check.inputn(c(n, length(lnmean), length(lnsd), length(u), length(xi), length(phiu)))
+  n = check.inputn(c(n, length(lnmean), length(lnsd), length(u), length(xi), length(phiu)),
+                   allowscalar = TRUE)
 
   if (any(xi == 1)) stop("shape cannot be 1")
   
